@@ -374,6 +374,7 @@ PDF_MAKE_NAME("N", N)
 PDF_MAKE_NAME("Name", Name)
 PDF_MAKE_NAME("Named", Named)
 PDF_MAKE_NAME("Names", Names)
+PDF_MAKE_NAME("NeedAppearances", NeedAppearances)
 PDF_MAKE_NAME("NewWindow", NewWindow)
 PDF_MAKE_NAME("Next", Next)
 PDF_MAKE_NAME("NextPage", NextPage)
@@ -464,6 +465,7 @@ PDF_MAKE_NAME("REx", REx)
 PDF_MAKE_NAME("RGB", RGB)
 PDF_MAKE_NAME("RI", RI)
 PDF_MAKE_NAME("RL", RL)
+PDF_MAKE_NAME("RO", RO)
 PDF_MAKE_NAME("ROpenArrow", ROpenArrow)
 PDF_MAKE_NAME("RP", RP)
 PDF_MAKE_NAME("RT", RT)
